@@ -1,5 +1,6 @@
 from optparse import OptionParser as OptParser, SUPPRESS_HELP
 
+
 class OptionParser(OptParser):
 
     def __init__(self, usage, version):
@@ -21,13 +22,14 @@ class OptionParser(OptParser):
         self.add_option('-o', '--output', dest='output_format', help='Set the output format for the episodes being renamed.')
         self.add_option('--organise', action='store_true', dest='organise', help='Organise renamed files into folders based on their show name and season number.')
         self.add_option('--no-organise', action='store_false', dest='organise', help='Explicitly tell Tv Renamr not to organise renamed files. Used to override the config.')
+        self.add_option('-p', '--partial', action='store_true', dest='partial', help='Allow partial regex matching of the filename.')
         self.add_option('-q', '--quiet', action='store_true', dest='quiet', help='Don\'t output logs to the command line')
         self.add_option('-r', '--recursive', action='store_true', dest='recursive', help='Recursively lookup files in a given directory')
         self.add_option('--rename-dir', dest='rename_dir', help='The directory to move renamed files to, if not specified the working directory is used.')
         self.add_option('--no-rename-dir', action='store_false', dest='rename_dir', help='Explicity tell Tv Renamr not to move renamed files. Used to override the config.')
         self.add_option('--regex', dest='regex', help='The regular expression to use when extracting information from files.')
         self.add_option('-s', '--season', dest='season', help='Set the season number.')
-        self.add_option('--show', dest='show', help='Set the show\'s name (will search for this name).')
+        self.add_option('--show', dest='show_name', help='Set the show\'s name (will search for this name).')
         self.add_option('--show-override', dest='show_override', help='Override the show\'s name (only replaces the show\'s name in the final file)')
         self.add_option('-t', '--the', action='store_true', dest='the', help='Set the position of \'The\' in a show\'s name to the end of the show name')
 
